@@ -8,6 +8,5 @@ fortran programming language.
 The repostory is named Flinter, because Flint was a namespace already taken on PYPi.
 """
 
-from .struct_analysis import *
-from .fmt_analysis import *
-from .formatting import *
+
+__version__ = "0.6.0"
